from pydantic import BaseModel
from typing import List
from ..model.Duration import Duration
from ..model.Orbit import Orbit


class Mission(BaseModel):
    mission: str
    astronauts: List[str]
    program: str
    call_sign: str
    image_url: str
    launch_date_utc: str
    launch_mass_lbs: str
    launch_site: str
    launch_site_coord: str
    launch_vehicle: str
    landing_date_utc: str
    landing_site: str
    landing_site_coord: str
    recovery_ship: str
    duration: Duration
    earth_orbit: Orbit
    target_orbit: Orbit



from setuptools import setup, find_packages
from os import getenv

setup(
    name='space-exploration-common-lib',
    version=getenv('VERSION', '0.0.1'),
    packages=find_packages(where='src', exclude=['tests']),
    package_dir={'': 'src'},
    python_requires='>=3.12, <4',
    include_package_data=True,
    install_requires=[
        'pydantic==2.8.2'
    ],
    author='Steven Hatch',
    author_email='stevegreghatch@gmail.com',
    description='A common library for space exploration projects',
    long_description='A common library for space exploration projects'
)
